Dual-functional Memory and Threshold Resistive Switching Based on the Push-Pull Mechanism of Oxygen Ions | Scientific Reports
Author: Yi-Jen Huang
Description: The combination of nonvolatile memory switching and volatile threshold switching functions of transition metal oxides in crossbar memory arrays is of great potential for replacing charge-based flash memory in very-large-scale integration. Here, we show that the resistive switching material structure, (amorphous TiOx)/(Ag nanoparticles)/(polycrystalline TiOx), fabricated on the textured-FTO substrate with ITO as the top electrode exhibits both the memory switching and threshold switching functions. When the device is used for resistive switching, it is forming-free for resistive memory applications with low operation voltage (<±1 V) and self-compliance to current up to 50 μA. When it is used for threshold switching, the low threshold current is beneficial for improving the device selectivity. The variation of oxygen distribution measured by energy dispersive X-ray spectroscopy and scanning transmission electron microscopy indicates the formation or rupture of conducting filaments in the [cell cut: 1272 characters, first 1000 kept]
Keywords: Electrical and electronic engineering
Date: 2016-04-07

Skip to main content

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

Advertisement

Dual-functional Memory and Threshold Resistive Switching Based on the Push-Pull Mechanism of Oxygen Ions
Download PDF

- Open Access
- Published: 07 April 2016

# Dual-functional Memory and Threshold Resistive Switching Based on the Push-Pull Mechanism of Oxygen Ions

- Yi-Jen Huang1,
- Shih-Chun Chao2,
- Der-Hsien Lien1,
- Cheng-Yen Wen2,4,
- Jr-Hau He3 &
- Si-Chen Lee
  1

Scientific Reports volume 6, Article number: 23945 (2016) Cite this article

- 1254 Accesses

- 28 Citations

- 0 Altmetric

- Metrics details

### Subjects

- Electrical and electronic engineering
- Electronic devices
- Electronic properties and materials

## Abstract

The combination of nonvolatile memory switching and volatile threshold switching functions of transition metal oxides in crossbar memory arrays is of great potential for replacing charge-based flash memory in very-large-scale integration. Here, we show that the resistive switching material structure, (amorphous TiOx)/(Ag nanoparticles)/(polycrystalline TiOx), fabricated on the textured-FTO substrate with ITO as the top electrode exhibits both the memory switching and threshold switching functions. When the device is used for resistive switching, it is forming-free for resistive memory applications with low operation voltage (<±1 V) and self-compliance to current up to 50 μA. When it is used for threshold switching, the low threshold current is beneficial for improving the device selectivity. The variation of oxygen distribution measured by energy dispersive X-ray spectroscopy and scanning transmission electron microscopy indicates the formation or rupture of conducting filaments in the device at different resistance states. It is therefore suggested that the push and pull actions of oxygen ions in the amorphous TiOx and polycrystalline TiOx films during the voltage sweep account for the memory switching and threshold switching properties in the device.

Download PDF

## Introduction

In the near future, the present charge-based flash memories will face the limits to their applications in the very-large-scale integration (VLSI) technology1,2,3. In order to have compatible storage devices with future high-frequency electronics, several types of non-volatile memory have been developed, such as ferroelectric random access memory (FRAM)4,5,6, magnetoresistive RAM (MRAM)7,8,9 and phase-change RAM (PRAM)10,11,12,13, etc. Among these new memory technologies, resistive random access memory (RRAM) has several properties outweighing the transistor-type memories, such as high-speed operation (sub-ns), low power consumption (<0.1 pJ), and high endurance (>1012 cycles)14,15,16,17,18,19,20,21,22; it is therefore the most promising candidate to overcome the technological limitations for next-generation non-volatile memory. More importantly, the simpler structure of RRAM makes it feasible to be integrated into a passive crossbar array of high-density memory cells with a cell size of 4F2 (F = minimum feature size;). By stacking up the crossbar arrays, a higher density of memory devices can be achieved23. Nonetheless, the sneak current through neighboring cells is still a problem in the crossbar array structure. Thus, selector devices are needed in the circuit to suppress the sneak current paths24,25. In order to replace conventional charge-based transistor selectors, which require a large space on the chip, for future memory technology in VLSI, smaller bi-directional selector devices, such as the mixed-ionic-electronic-conduction device26,27, bipolar nonlinear device28,29, and the Schottky diodes30,31, have recently been incorporated into bipolar RRAM devices.

A material with the resistive switching (RS) characteristics can be used for non-volatile memory switching (MS) or volatile threshold switching (TS). The low-resistance state (LRS) or the high-resistance state (HRS) of the material can be stably maintained without an external sustaining voltage. This property provides attractive prospects for non-volative RRAM applications. When the resistive switching material is used for TS applicaitons, the “ON” and “OFF” states of the device are switchable by adjusting the voltage32,33. Such TS devices typically exhibit bi-directional switching property, useful for suppressing the sneak current paths between memory cells34,35,36,37,38,39,40. Recently, it is found that the MS and TS operations can be realized in a single device structure32,33,41,42. When such a dual-functional device is operated in the MS mode, it is used for the non-volatile memory storage; when it is operated in the TS mode, it is a bi-directional selector device. The flexibility and simplicity for the MS and TS applications in a single device is beneficial for the advancement of integrated-circuit design.

In this paper, we show that the memory switching and threshold switching can both be operated in a particular (amorphous TiOx)/(Ag nanoparticles)/(polycrystalline TiOx) structure sandwiched between indium tin oxide (ITO) and fluorine-doped tin oxide (FTO) electrodes. When this device is used for memory switching, it exhibits good electrical properties, especially, the self-compliant driving current, which is beneficial for ultralow programming energy in RRAM applications. When an external current compliance is applied, the device can be operated for threshold switching. It is then an excellent bi-directional selector for high-density memory applications. In order to understand the electrical conduction mechanism of this device, we use scanning transmission electron microscopy (STEM) and energy dispersive spectroscopy (EDS) to study the compositional distribution in the devices at different resistance states. The results suggest that, under voltage sweeps, the push and pull actions on the oxygen ions in the amorphous TiOx layer and polycrystalline TiOx layer can account for both the memory switching and threshold switching operations in the device.

## Results

### Dual-functional resistive switching device structure and its electrical properties

The active layer of the dual-functional switching device is composed of an amorphous TiOx layer, Ag nanoparticles, and a polycrystalline TiOx layer. This active layer is fabricated on the textured-FTO bottom electrode, followed by the deposition of the ITO top electrode (Details of device fabrication can be found in Methods). Figure 1(a) shows the schematic illustration and the cross-sectional STEM image of the device structure. The as-deposited device is already in the high-resistance state, so that the bias-assisted forming process is not required for the resistive switching operation43.

Figure 1: Device structure and electrical properties of the dual functional switching device.

(a) Schematic illustration of the (amorphous TiOx)/(Ag nanoparticles)/(polycrystalline TiOx) resistive switching material fabricated on the textured-FTO (fluorine doped tin oxide) glass substrate with ITO (indium tin oxide) as the top electrode. The inset shows the cross-sectional scanning transmission electron microscopy (STEM) image. (b) Current-voltage (I-V) curves of the device operated in the memory switching mode of the first, 10th, and 100th cycles, respectively. Vset and Vreset are respectively the setting and resetting voltages used for memory switching. (c) I-V curves of the device operated in the threshold switching mode of the first, 5th, and 10th cycles, respectively. Vth (−Vth) is the voltage to switch the device to the ON state, and Vhold (−Vhold) is the voltage to switch the device to the OFF state.

Full size image

Figure 1(b) shows the typical current-voltage (I-V) curves of the device in the memory switching mode. When a negative voltage sweep (0 V to −0.8 V) is applied on the top electrode, the current increases rapidly at the SET voltage (Vset≈ −0.5 V); the device is switched from the high resistance state (HRS) to the low resistance state (LRS). When the voltage is swept reversely to 0.3 V, the device is switched back to HRS at the RESET voltage (Vreset≈ 0.2 V). This memory-switching characteristic sustains after 100 switching cycles. It is noted that, when the voltage is more negative than Vset, the current obeys linear I-V relation (Supplementary Fig. S1(a)) up to 50 μA. Without such a self-compliance property, an external current limit (so-called compliance current) is required. Otherwise, a large current may be produced to cause eternal device failure, so called the hard breakdown, during the forming or setting process. An RRAM device with the self-compliance property is beneficial for the development of high-density memory array or 3D RRAM applications, because an extra transistor-type current-compliance unit is no longer required.

When a current compliance (Icc= 10 μA) is subsequently applied on the device of Fig. 1(b), the I-V relation shows the characteristics of threshold switching mode, as shown in Fig. 1(c) (linear I-V relations are plotted in Supplementary Fig. S1(b)). The device is switched from the OFF state to the ON state, when the voltage is swept to higher than −Vth= −0.8 V (step 1). As the voltage is swept reversely, the current follows the compliance current until the hold voltage, −Vhold= −0.2 V (step 2). The device is then switched back to the OFF state. Similar switching phenomenon occurs in the positive voltage sweep (steps 3 and 4). This threshold-switching characteristic remains similar after 10 successive cycles. In principle, Vth in Fig. 1(c) and Vset in Fig. 1(b) should be identical. However, there is distribution of the values of Vset (as will be shown in Fig. 2(d)). The variation of the value of Vth from Vset is still within the range of the distribution.

Figure 2: Electrical characteristics of memory switching device of the resistive switching material.

(a) Resistance of the device at HRS and LRS at different switching cycles. (b) Resistances of the devices at HRS and LRS vs. time. The retention of the resistance state is at least 104s. (c) Cumulative probability plots from (a) for the resistances of the device at HRS and LRS, respectively. (d) Distribution of the set and reset voltages in 100 successive cycles. Vset is −0.52 ± 0.13 V, and Vreset is 0.24 ± 0.05 V.

Full size image

From Fig. 1(c), assuming that a reading voltage is applied between −Vth and −Vhold, the on/off ratio of the selector device is higher than 10. It is also noted that the TS device has low threshold currents, −Ith= −2 μA and Ith= 0.1 μA, at −Vth= −0.8 V and Vth= 0.4 V, respectively. Once the TS device is in series with a memory device (so-called 1S + 1R structure) in a memory array, reading memory cells can be accurate for that the problem of sneak current is reduced39,40. Figure 1(b,c) demonstrate that the device in Fig. 1(a) can be operated in both the memory switching and threshold switching modes; in addition, when it is operated in the threshold switching mode, it is a bi-directional selector.

### Electrical performance for the memory switching and threshold switching operations

The reliability of the resistive switching device in the MS mode is demonstrated in its cycling endurance and retention time tests, as shown respectively in Fig. 2(a,b). In 100 sweeping cycles, the resistances at HRS and LRS, read at −0.1 V, are consistently in a ratio of ~200, as shown in Fig. 2(a). The device is therefore very suitable for memory applications. Figure 2(b) shows the retention of the device at both HRS and LRS at room temperature for 104s with the reading voltage of −0.1 V. The resistances of the device at HRS and LRS are also uniform, as shown in Fig. 2(c), with mean values of 12 MΩ and 60 KΩ, respectively. The variation of the SET and RESET voltages of this device are also small (Fig. 2(d)); Vset is −0.52 ± 0.13 V, and Vreset is 0.24 ± 0.05 V.

To understand the conduction mechanism in the memory switching mode, the I-V curves of the device, (amorphous TiOx)/(Ag NPs)/(polycrystalline TiOx) with ITO and textured-FTO as the electrodes, in both SET (negative voltage region) and RESET (positive voltage region) processes are plotted respectively in Fig. 3(a,b) in double-logarithmic scale. In the SET process of the device at HRS (Fig. 3(a)), the current varies linearly with voltage (I V) in the small bias region, followed by the quadratic dependence (I V2) in the larger bias region. Such I-V relation is in agreement with the characteristics of the trap-controlled space-charge-limited current44,45,46,47, and the dominating trap sites in this device are the oxygen vacancies in the structure. After the SET process, the conducting filament is formed. Thus, the I-V relation presents the ohmic conduction behavior (I V) at LRS. A similar conducting mechanism is also noted in the RESET process, as shown in Fig. 3(b). A linear I-V relation appears at LRS, and the space-charge-limited current again dominates the conduction after the RESET process.

Figure 3: Electrical characteristics of the resistive switching device in the memory switching and threshold switching modes.

(a,b) Double-logarithmic plots of I-V curves of the memory switching operation in the negative and positive bias regions, respectively. (c,d) Double-logarithmic plots of I-V curves of the threshold switching operation in the negative and positive bias regions, respectively.

Full size image

When operated in the threshold switching mode, the device at HRS in the turn-on process exhibits a nearly linear relation at low voltage regions, in both negative and positive sweeping (Fig. 3(c,d)), followed by a more rapidly increasing current in higher voltage regions. A steeper increase of current is noticed between −0.5 V to −0.8 V (Fig. 3(c)). These features are also in agreement with the trap-controlled space-charge-limited current model44,45. After the device is turned off, the device exhibits the ohmic conduction property. Because of the similarities in current-voltage characteristics between the memory switching and threshold switching operations, it is believed that the mechanisms of device operation in both modes are similar.

### Composition redistribution during memory switching of the device

The as-prepared device at the initial resistance state (IRS) and those after the SET process (LRS), and after the RESET process (HRS) are analyzed using STEM. The voltage sweeps, and the corresponding I-V curves, for making the LRS and HRS samples are shown in Supplementary Fig. S2. Figure 4(a–c) displays the STEM high-angle annular dark-field (HAADF) images and the EDS analysis of the three samples. In the HAADF-STEM images, the intensity is sensitively proportional to Z1.7, where Z is the atomic number, revealing compositional information; therefore, the top and bottom electrodes and the Ag nanoparticles appear bright, while the TiOx layers are darker. It is also noted that the area of the top amorphous TiOx layer is brighter than that of the bottom polycyrstalline TiOx layer, implying the existence of heavier elements other than Ti and O. From the EDS composition maps of indium in Fig. 4(a–c), the brighter contrast in the amorphous TiOx layer is due to the diffusion of indium from the top ITO electrode. Therefore, the top amorphous TiOx layer should contain a noticeable amount of indium during resistive switching.

Figure 4: STEM-EDS analysis of the resistive switching cell at different resistance states.

The cross-sectional STEM images and the EDS compositional maps of the resistive switching cell at (a) the initial resistance state (IRS), (b) the low resistance state (LRS), and (c) the high resistance state (HRS). The EDS maps of In, Ag, O, and Ti are measured from the indicated area in each STEM image. Region I is the area between Ag nanoparticles and the top ITO electrode in the amorphous TiOx layer. Region II is the area between the bottom FTO electrode and the Ag nanoparticles in the polycrystalline TiOx layer. (d,e) Plots of the atomic ratio of oxygen in region I and region II, respectively, at different resistance states. These values are calculated from the EDS spectra probed in these regions.

Full size image

It has been reported that, in the TiO2-based RRAM devices, the resistive switching is via the formation or rupture of the Magnéli phase (TinO2n−1; n = 3, 4, 5…), which is oxygen deficient and exhibits n-type semiconducting properties18,48,49. When oxygen ions migrate out of the resistive switching layer due to an applied electric field, oxygen vacancies accumulate to form filaments (channels) of the oxygen-deficient TiOx channel. On the other hand, when oxygen ions migrate into the resistive switching layer, the oxygen vacancies are being filled. Therefore, the conducting filaments shrink, making the resistive switching layer more insulating. Indium oxide also exhibits similar resistive switching properties50. It is therefore suggested that, in the RRAM devices of Fig. 4, the amorphous TiOx together with indium oxide play the role as the resistive switching layer.

In this study, textured-FTO substrates are used as the bottom electrodes. The titanium oxide resistive switching layer, deposited by ALD (Methods), conformally covers the bottom electrode. The textured-FTO substrate can also enhance the electrical field near the tips on the surface51,52. When a voltage is applied on this structure, the electric field around the metal particles is also enhanced in the direction parallel to the voltage. Therefore, the electric field between the tips of bottom FTO electrode and the Ag nanoparticle is enhanced to form or rupture the conducting filaments53,54,55. Likewise, the electric field between the Ag nanoparticles and top electrode is also enhanced. As a result of the migration of oxygen ions under the enhanced electric fields, the relative content of oxygen in the regions surrounding the Ag nanoparticles varies at different resistance states as shown in Fig. 4. In such a device structure, Au is also one of the candidates for the nanoparticles. Under similar growth conditions to the Ag nanoparticles in this study, the average particles size of Au nanoparticles is about 16 nm, smaller than that of the Ag nanoparticles, and the density of Au nanoparticles is larger. The thickness of the TiOx resistive switching layer between the Au nanoparticles and the ITO electrode in the device is thicker, so that the effect of field enhancement is weaker. A larger voltage is required to operate the device. Besides, due to the density of Au nanoparticles is higher, the number of conducting filaments is larger, leading to larger currents (Supplementary Fig. S3) and larger power consumption than those shown in Fig. 1(b). For the device without the metal particles, the forming step for memory switching causes the formation of pores in the TiOx layer (Supplementary Fig. S4), and the endurance and reliability are degraded.

Representative composition ratios of O over the transition metals (Ti and In), calculated from the EDS spectra (Supplementary Fig. S5) of the top amorphous TiOx layer (region I) and the bottom poly-crystalline TiOx layer (region II) at each resistance state are plotted in Fig. 4(d,e). At IRS (Fig. 4(a)), the oxygen is deficient (O/(Ti+In) = 1.1) in region I, implying the existence of conducting filament. By contrast, the O/Ti ratio is about 2 in region II, making the layer less conducting. When a negative bias is swept to the setting voltage Vset, the device is set to LRS (Fig. 4(b)) (Supplementary Fig. S2(a)). The negative bias pushes oxygen ions from the top ITO electrode to region I, and the O/(Ti+In) ratio increases to 1.6. At this process, recombination of oxygen ions with vacancies leads to the rupture of the conducting filaments, so that region I at LRS is less conductive than that at IRS. In region II, the relatively positive bias on the FTO bottom electrode pulls oxygen ions from region II to the electrode, making region II (O/Ti = 1.3) at LRS more conductive than that at IRS.

Reversed movement of oxygen ions occurs when a positive bias is swept over the resetting voltage, Vreset (Supplementary Fig. S2(b)), making the device at HRS (Fig. 4c). At this state, some of the oxygen ions in region I have been pulled back to the ITO top electrode, and region I becomes more oxygen-deficient (O/(Ti+In) = 1.1) and more conductive than that at LRS. Meanwhile, oxygen ions are pushed into region II from the FTO bottom electrode, making region II less oxygen-deficient (O/Ti = 1.5) and more insulating than that at LRS.

## Discussion

According to the STEM-EDS analysis results in Fig. 4, the resistive switching of device is due to the push-pull mechanism of the oxygen ions in the top amorphous TiOx layer and the bottom polycrystalline TiOx layer under enhanced electrical fields. Figure 5(a–d) schematically explains the migration of oxygen ions during the setting and resetting steps. In the as-prepared device, Fig. 5(a), the top amorphous TiOx region is oxygen-deficient, with many conducting filaments, and the bottom polycrystalline TiOx is oxygen-rich, without conducting filaments (according to the EDS results of the IRS sample in Fig. 4(a)).

Figure 5: Push-pull mechanism of oxygen ions migration in the memory and threshold switching modes.

(a–d) Schematic illustrations of the migration of the oxygen ions due to the applied voltage. After device preparation, the concentration of oxygen vacancies (grey circles) at the initial resistance state (IRS) is high in the amorphous TiOx layer (a). After applied a negative voltage, oxygen ions (blue circles) are pushed (indicated by red arrows) into the amorphous TiOx (a-TiOx) layer and recombine with the oxygen vacancies (b). Thus, the filament (the dashed box) in the a-TiOx layer shrinks. In the polycrystalline TiOx (poly-TiOx) layer, oxygen ions are pulled (indicated by orange arrows) to the bottom electrode. Filaments are therefore formed in both a-TiOx and poly-TiOx layers, and the cell is switched to the low-resistance state (LRS) (c). When a positive voltage is applied, oxygen ions in the a-TiOx layer are pulled out to the top electrode. Meanwhile, some oxygen ions are pushed from the bottom electrode to the poly-TiOx layer. Recombination of oxygen ions with the vacancies in the poly-TiOx layer causes dissolution of the filaments, indicated by the black break lines in (d). The sample is at the high-resistance state (HRS). (e–h) Schematic illustrations of the migration of oxygen ions to switch the device to the ON state (e,g) and the OFF state (f,h).

Full size image

During the SET process (Fig. 5(b)), a negative voltage sweep pulls the oxygen ions from the polycrystalline TiOx layer to the bottom electrode. Once the oxygen vacancies form a conducting filament, the current increases abruptly and the device is switched to LRS. Meanwhile, a large amount of electrons are injected from top ITO electrode into the amorphous TiOx film. These electrons enhance (push) the oxygen ions migration from the top ITO electrode to the amorphous TiOx layer. The oxygen ions recombine with oxygen vacancies, so that the existing conducting filament in this layer shrinks. As a result, the resistance in the top amorphous TiOx layer increases rapidly, leading to the self-compliance current (Fig. 5(c)). Thus, the device presents ohmic I-V relation, as shown in Fig. 3(a), and hard breakdown of the device is avoided.

During the RESET process, Fig. 5(d), the positive voltage sweep pulls the oxygen ions from the amorphous TiOx layer to the top ITO electrode, and pushes the oxygen ions from the bottom FTO electrode into the polycrystalline TiOx layer. Even though the conducting filament grows in the amorphous TiOx layer (as evidenced in Fig. 4(c), the oxygen concentration in region I decreases), the filaments in the polycrystalline TiOx layer shrink, making the device at HRS. The asymmetric I-V relation present in this device is perhaps due to the difference between the oxygen migration rates across the ITO/amorphous TiOx and polycrystalline TiOx/FTO interfaces.

To operate the device for threshold switching, the current compliance is required; furthermore, the range of voltage sweep is wider in threshold switching than that in memory switching. For setting the device to the ON state (step 1 in Fig. 1(c)), the negative voltage sweep drives the migration of oxygen ions to form filaments in the polycrystalline TiOx (Fig. 5(e)). When the bias is reduced, step 2 in Fig. 1(c), the current is still maintained at the compliance current. The current flow through the top ITO electrode also causes the migration of oxygen ions to fill the oxygen vacancies in the amorphous TiOx layer. In contrast to memory switching, the prolonged migration of oxygen ions and accompanied Joule heating rupture the existing conducting filaments, and the device is switched to the high resistance OFF state (Fig. 5(f)). The device is therefore has the volatile memory property. The positive voltage sweep also switches the device to the ON and OFF states (steps 3 and 4 in Fig. 1(c)) in similar mechanisms, as shown in Fig. 5(g,h), respectively.

In summary, dual-functional resistive switching devices for nonvolatile memory switching and volatile threshold switching applications can be realized in a structure composed of (amorphous TiOx)/(Ag NPs)/(polycrystalline TiOx) with ITO and textured-FTO as the electrodes. The resistive switching is due to the formation and rupture of conducting filaments in the TiOx layers between Ag nanoparticles and the electrodes, where the electric fields are enhanced. Migration of oxygen ions due to the enhanced electric fields is observed in the STEM-EDS composition analysis. Based on the push-pull mechanism, the migration of oxygen ions accounts for the formation and rupture of the conducting filaments, which are made of oxygen-deficient TiOx structure. This resistive switching device is forming-free, with low (<±1 V) and uniform setting and resetting voltages. It also has uniform resistance at HRS and LRS and the self-compliant current-voltage relation for RRAM applications. By applying a compliance current (10 μA), the device is operated in the threshold switching mode and can be a bipolar selector with a high on/off ratio.

## Methods

### Device fabrication

A 10 nm amorphous titanium oxide (TiOx) thin film was deposited on a textured-FTO (~300 nm) on glass substrate using atomic layer deposition (ALD) with titanium isopropoxide (Ti(OCH(CH3)2)4, TTIP) as the titanium precursor and H2O as the oxygen precursor at 200 °C. Then the sample was annealed at 500 °C in oxygen for 5 min using the rapid thermal annealing (RTA) process. During the RTA process, the amorphous TiOx thin film transforms into the polycrystalline anatase TiOx phase.

A 3 nm thick Ag film was thermally evaporated onto the polycrystalline TiOx thin films at a rate of 0.1 Å/s in the vacuum of 4 × 10−6Torr. The subsequent annealing at 300 °C for 5 min in nitrogen aggregated the Ag films to form nanoparticles. The average diameter was approximately 25 nm (Supplementary Fig. S6). Under the same sample growth conditions, the average diameter of Au nanoparticles was around 16 nm (Supplementary Fig. S7).

After the formation of Ag NPs, a 10 nm amorphous TiOx film was deposited onto the sample surface using ALD at 200 °C. The top ITO electrode in a thickness of 100 nm was deposited in a DC Ar plasma sputtering system at 150 °C. The electrodes are in a diameter of 250 μm, defined by a shadow mask during deposition.

### Electrical measurements

The current-voltage curves, cycling endurance, and data retention of the devices were measured by a Keithley 4200 semiconductor parameter analyzer. While a DC voltage was applied to the top ITO electrode, the bottom FTO electrode was grounded. For testing the device in the memory switching mode, no current compliance was needed to avoid the hard breakdown problems, but, in the threshold switching mode, a current compliance was required.

### Sample preparation for scanning transmission electron microscopy analysis

Specimens of the device cells at the initial resistance state (IRS), after switched to the low resistance state (LRS), and after switched back to the high resistance state (HRS) were respectively prepared in a focused ion beam (FIB) system, FEI Helios 600i. STEM imaging and EDS analysis of these specimens were conducted in a 200 kV FEI Tecnai Osiris transmission electron microscope.

## Additional Information

How to cite this article: Huang, Y.-J. et al. Dual-functional Memory and Threshold Resistive Switching Based on the Push-Pull Mechanism of Oxygen Ions. Sci. Rep. 6, 23945; doi: 10.1038/srep23945 (2016).

## References

1. 1

   Waser, R. (ed.) Nanoelectronics and Information Technology Ch. 4 (Wiley-VCH, 2003).

2. 2

   Lu, J. et al. Enhanced retention characteristic of NiSi2/SiNx compound nanocrystal memory. Appl. Phys. Lett. 96, 262107 (2010).

   ADS Google Scholar

3. 3

   Chang, T. C., Jian, F. Y., Chen, S. C. & Tsai, Y. T. Developments in nanocrystal memory. Mater. Today 14, 608–615 (2011).

   CAS Google Scholar

4. 4

   Scott, J. F. & Argujo, C. A. P. Ferroelectric memories. Science 246, 1400–1405 (1989).

   CAS ADS Google Scholar

5. 5

   Scott, J. F. Applications of modern ferroelectrics. Science 315, 954–959 (2007).

   CAS ADS PubMed PubMed Central Google Scholar

6. 6

   Guo, R. et al. Non-volatile memory based on the ferroelectric photovoltaic effect. Nat. Commun. 4, 1990, doi: 10.1038/ncomms2990 (2013).

   CAS ADS Article PubMed PubMed Central Google Scholar

7. 7

   Zhu, J. G. Magnetoresistive random access memory: the path to competitiveness and scalability. Proc. IEEE 96, 1786–1798 (2008).

   Google Scholar

8. 8

   Liu, H. et al. Ultrafast switching in magnetic tunnel junction based orthogonal spin transfer devices. Appl. Phys. Lett. 97, 242510 (2010).

   ADS Google Scholar

9. 9

   Hu, J. M., Li, Z., Chen, L. Q. & Nan, C. W. High-density magnetoresistive random access memory operating at ultralow voltage at room temperature. Nat. Commun. 2, 553; doi: 10.1038/ncomms1564 (2011).

   CAS ADS Article PubMed PubMed Central Google Scholar

10. 10

    Hamann, H. F. et al. Ultra-high-density phase-change storage and memory. Nature Mater. 5, 383–387 (2006).

    CAS ADS Google Scholar

11. 11

    Kuzum, D., Jeyasingh, R., Lee, B. & Wong, H.-S. P. Nanoelectronic programmable synapses based on phase change materials for brain-inspired computing. Nano Lett. 12, 2179–2186 (2011).

    ADS PubMed Google Scholar

12. 12

    Cassinerio, M., Ciocchini, N. & Ielmini, D. Logic computation in phase change materials by threshold and memory switching. Adv. Mater. 25, 5975–5980 (2013).

    CAS PubMed Google Scholar

13. 13

    Sebastian, A., Gallo, M. L. & Krebs, D. Crystal growth within a phase change memory cell. Nat. Commun. 5, 4314; doi: 10.1038/ncomms5314 (2014).

    CAS ADS Article PubMed Google Scholar

14. 14

    Waser, R. & Aono, M. Nanoionics-based resistive switching memories. Nat. Mater. 6, 833–840 (2007).

    CAS ADS PubMed Google Scholar

15. 15

    Sawa, A. Resistive switching in transition metal oxides. Mater. Today 11, 28–36 (2008).

    CAS Google Scholar

16. 16

    Yang, J. J. et al. Memristive switching mechanism for metal/oxide/metal nanodevices. Nat. Nanotechnol. 3, 429–433 (2008).

    CAS PubMed Google Scholar

17. 17

    Waser, R., Dittmann, R., Staikov, G. & Szot, K. Redox-based resistive switching memories nanoionic mechanisms, prospects, and challenges. Adv. Mater. 21, 2632–2663 (2009).

    CAS Google Scholar

18. 18

    Kwon, D. H. et al. Atomic structure of conducting nanofilaments in TiO2 resistive switching memory. Nat. Nanotechnol. 5, 148–153 (2010).

    CAS ADS Google Scholar

19. 19

    Lee, M. J. et al. A fast, high-endurance and scalable non-volatile memory device made from asymmetric Ta2O5−x/TaO2−x bilayer structures. Nat. Mater. 10, 625–630 (2011).

    CAS ADS PubMed Google Scholar

20. 20

    Wong, H.-S. P. et al. Metal-oxide RRAM. Proc. IEEE. 100, 1951–1970 (2012).

    CAS Google Scholar

21. 21

    Yang, J. J., Strukov, D. B. & Stewart, D. R. Memristive devices for computing. Nat. Nanotechnol. 8, 14–24 (2013).

    ADS Google Scholar

22. 22

    Pan, F. et al. Recent progress in resistive random access memories: Materials, switching mechanisms, and performance. Mater. Sci. Eng., R. 83, 1–59 (2014).

    ADS Google Scholar

23. 23

    Kawahara, A. et al. An 8 Mb multi-layered cross-point ReRAM macro with 443MB/s write throughput. IEEE Journal of Solid-State Circuits. 48(1), 178–185 (2013).

    ADS Google Scholar

24. 24

    Linn, E., Rosezin, R., Kugeler, C. & Waser, R. Complementary resistive switches for passive nanocrossbar memories. Nat. Mater. 9, 403–406 (2010).

    CAS ADS PubMed PubMed Central Google Scholar

25. 25

    Lee, M. J. et al. A plasma-treated chalcogenide switch device for stackable 3D nanoscale memory. Nat. Commun. 4, 2629, doi: 10.1038/ncomms3629 (2013).

    CAS ADS Article PubMed PubMed Central Google Scholar

26. 26

    Burr, G. W. et al. Large-scale (512kbit) integration of multilayer-ready access-devices based on mixed-ionic-electronic-conduction (MIEC) at 100% yield. VLSI Technol. 41–42, doi: 10.1109/VLSIT.2012.6242451 (2012).

27. 27

    Shenoy, R. S. et al. MIEC (mixed-ionic-electronic-conduction) based access devices for non-volatile crossbar memory arrays. Semicond. Sci. Technol. 29, 104005 (2014).

    ADS Google Scholar

28. 28

    Huang, J. J., Tseng, Y. M., Hsu, C. W. & Hou, T. H. Bipolar nonlinear Ni/TiO2/Ni selector for 1S1R crossbar array applications. IEEE Electron Device Lett. 32, 1427–1429 (2011).

    CAS ADS Google Scholar

29. 29

    Lee, W. et al. High current density and nonlinearity combination of selection device based on TaOx/TiO2/TaOx structure for one selector-one resistor arrays. ACS nano 6, 8166–8172 (2012).

    CAS PubMed Google Scholar

30. 30

    Li, Y. et al. Bipolar one diode-one resistor integration for high-density resistive memory applications. Nanoscale 5, 4785–4789 (2013).

    CAS ADS PubMed Google Scholar

31. 31

    Li, Y., Gong, Q. & Jiang, X. Feasibility of schottky diode as selector for bipolar-type resistive random access memory applications. Appl. Phys. Lett. 104, 132105 (2014).

    ADS Google Scholar

32. 32

    Peng, H. Y. et al. Deterministic conversion between memory and threshold resistive switching via tuning the strong electron correlation. Sci. Rep. 2, 442, doi: 10.1038/srep00442 (2012).

    CAS Article PubMed PubMed Central Google Scholar

33. 33

    Sun, H. et al. Direct observation of conversion between threshold switching and memory switching induced by conductive filament morphology. Adv. Funct. Mater. 24, 5679–5686 (2014).

    CAS ADS Google Scholar

34. 34

    Son, M. et al. Excellent selector characteristics of nanoscale VO2 for high-density bipolar ReRAM applications. IEEE Electron Device Lett. 32, 1579–1581 (2011).

    CAS ADS Google Scholar

35. 35

    Chang, S. H. et al. Oxide double-layer nanocrossbar for ultrahigh-density bipolar resistive memory. Adv. Mater. 23, 4063–4067 (2011).

    CAS PubMed PubMed Central Google Scholar

36. 36

    Son, M. et al. Self-selective characteristics of nanoscale VOx devices for high-density ReRAM applications. IEEE Electron Device Lett. 33, 718–720 (2012).

    CAS ADS Google Scholar

37. 37

    Liu, X. et al. Co-occurrence of threshold switching and memory switching in Pt/NbOx/Pt cells for crosspoint memory applications. IEEE Electron Device Lett. 33, 236–238 (2012).

    ADS Google Scholar

38. 38

    Kim, S. et al. Ultrathin (&lt;10nm) Nb2O5/NbO2 hybrid memory with both memory and selector characteristics for high density 3D vertically stackable RRAM applications. VLSI Technol. 155–156, doi: 10.1109/VLSIT.2012.6242508 (2012).

39. 39

    Cha, E. et al. Nanoscale (~10nm) 3D vertical ReRAM and NbO2 threshold selector with TiN electrode. Int. Electron Device Meeting 10.5.1–10.5.4, doi: 10.1109/IEDM.2013.6724602 (2013).

40. 40

    Liu, X. et al. Reduced threshold current in NbO2 selector by engineering device structure. IEEE Electron Device Lett. 35, 1055–1057 (2014).

    CAS ADS Google Scholar

41. 41

    Chang, S. H. et al. Occurrence of both unipolar memory and threshold resistance switching in a NiO film. Phy. Rev. Lett. 102, 026801 (2009).

    CAS ADS Google Scholar

42. 42

    Baek, Y. J. et al. Tunable threshold resistive switching characteristics of Pt-Fe2O3 core-shell nanoparticle assembly by space charge effect. Nanoscale 5, 772–779 (2013).

    CAS ADS PubMed Google Scholar

43. 43

    Jo, S. H. & Lu, W. CMOS Compatible Nanoscale Nonvolatile Resistance Switching Memory. Nano Lett. 8, 392–397 (2008).

    CAS ADS PubMed Google Scholar

44. 44

    Lampert, M. A. Volume-controlled current injection in insulators. Rep. Prog. Phys. 27, 329 (1964).

    CAS ADS MATH Google Scholar

45. 45

    Hou, T. H. et al. Evolution of RESET current and filament morphology in low-power HfO2 unipolar resistive switching memory. Appl. Phys. Lett. 98, 103511 (2011).

    ADS Google Scholar

46. 46

    Chang, Y. C. & Wang, Y. H. Resistive switching behavior in Gelatin thin films for nonvolatile memory application. ACS Appl. Mater. Interfaces 6, 5413–5421 (2014).

    CAS PubMed Google Scholar

47. 47

    Sun, Y. et al. High on-off ratio improvement of ZnO-based forming-free memristor by surface hydrogen annealing. ACS Appl. Mater. Interfaces 7, 7382–7388 (2015).

    CAS ADS PubMed Google Scholar

48. 48

    Park, S. J. et al. In situ control of oxygen vacancies in TiO2 by atomic layer deposition for resistive switching devices. Nanotechnology 24, 295202 (2013).

    PubMed Google Scholar

49. 49

    Szot, K. et al. TiO2-a prototypical memristive material. Nanotechnology 22, 254001 (2011).

    CAS ADS PubMed PubMed Central Google Scholar

50. 50

    Yang, J. B. et al. Low power consumption resistance random access memory with Pt/InOx/TiN structure. Appl. Phys. Lett. 103, 102903 (2013).

    ADS Google Scholar

51. 51

    Huang, Y. C. et al. High-performance programmable metallization cell memory with the pyramid-structured electrode. IEEE Electron Device Lett. 34, 1244–1246 (2013).

    CAS ADS Google Scholar

52. 52

    Kim, H. D., Yun, M. J., Hong, S. M. & Kim, T. G. Effect of nanopyramid bottom electrodes on bipolar resistive switching phenomena in nickel nitride films-based crossbar arrays. Nanotechnology 25, 125201 (2014).

    ADS PubMed Google Scholar

53. 53

    Liu, Q. et al. Controllable growth of nanoscale conductive filaments in solid-electrolyte-based ReRAM by using a metal nanocrystal covered bottom electrode. ACS nano 4, 6162–6168 (2010).

    CAS PubMed Google Scholar

54. 54

    Tsai, Y. T. et al. Influence of nanocrystals on resistive switching characteristic in binary metal oxides memory devices. Electrochem. Solid-State Lett. 14, H135–H138 (2011).

    CAS Google Scholar

55. 55

    Bousoulas, P., Sakellaropoulos, D., Giannopoulos, J. & Tsoukalas, D. Improving the resistive switching uniformity of forming-free TiO2−x based devices by embedded Pt nanocrystals. Proceedings of the European Solid-State Device Research Conference (ESSDERC), Graz, Austria, 274–277, doi: 10.1109/ESSDERC.2015.7324767 (2015).

Download references

## Acknowledgements

The authors would like to thank the Ministry of Science and Technology in Taiwan for financially supporting this research under Contract No. MOST 103-2622-E-002-031 and NSC 100-2112-M-002-019.

## Author information

### Affiliations

1. Graduate Institute of Electronics Engineering, National Taiwan University, Taipei, 10617, Taiwan

   Yi-Jen Huang, Der-Hsien Lien & Si-Chen Lee

2. Department of Materials Science and Engineering, National Taiwan University, Taipei, 10617, Taiwan

   Shih-Chun Chao & Cheng-Yen Wen

3. Electrical and Mathematical Sciences and Engineering (CEMSE) Division, Computer, King Abdullah University of Science & Technology (KAUST), Thuwal, 23955-6900, Saudi, Arabia

   Jr-Hau He

4. Taiwan Consortium of Emergent Crystalline Materials, Ministry of Science and Technology, Taipei, 10617, Taiwan

   Cheng-Yen Wen

Authors

1. Yi-Jen Huang
   View author publications

   You can also search for this author in PubMed Google Scholar

2. Shih-Chun Chao
   View author publications

   You can also search for this author in PubMed Google Scholar

3. Der-Hsien Lien
   View author publications

   You can also search for this author in PubMed Google Scholar

4. Cheng-Yen Wen
   View author publications

   You can also search for this author in PubMed Google Scholar

5. Jr-Hau He
   View author publications

   You can also search for this author in PubMed Google Scholar

6. Si-Chen Lee
   View author publications

   You can also search for this author in PubMed Google Scholar

### Contributions

Y.J.H., S.C.C. and S.C.L. designed and fabricated the devices. Y.J.H., D.H.L. and J.H.H. performed the electrical measurement. C.Y.W. performed the TEM analysis. Y.J.H., C.Y.W. and S.C.L. wrote the manuscript. All the authors discussed the results and explanations.

### Corresponding author

Correspondence to Si-Chen Lee.

## Ethics declarations

### Competing interests

The authors declare no competing financial interests.

## Supplementary information

### Supplementary Information (PDF 6922 kb)

## Rights and permissions

This work is licensed under a Creative Commons Attribution 4.0 International License. The images or other third party material in this article are included in the article’s Creative Commons license, unless indicated otherwise in the credit line; if the material is not included under the Creative Commons license, users will need to obtain permission from the license holder to reproduce the material. To view a copy of this license, visit http://creativecommons.org/licenses/by/4.0/

Reprints and Permissions

## About this article

### Cite this article

Huang, YJ., Chao, SC., Lien, DH. et al. Dual-functional Memory and Threshold Resistive Switching Based on the Push-Pull Mechanism of Oxygen Ions. Sci Rep 6, 23945 (2016). https://doi.org/10.1038/srep23945

Download citation

- Received: 30 October 2015

- Accepted: 15 March 2016

- Published: 07 April 2016

- DOI: https://doi.org/10.1038/srep23945

## Further reading

- ### Swift heavy ion irradiation induced negative differential resistance and transport of charge carriers in conducting polymer-metal oxide hybrids

  - Jitendra Singh
  - , R.G. Singh
  - , Subodh K. Gautam
  - , Himanshi Gupta
  - , Sunil Ojha
  - & Fouran Singh

  Radiation Physics and Chemistry (2021)

- ### A versatile multifaceted resistive switching memory activated by light and ion irradiation in poly (3-octylthiophene)-zinc oxide hybrids

  - Jitendra Singh
  - , R.G. Singh
  - , Subodh K. Gautam
  - , Himanshi Gupta
  - & Fouran Singh

  Organic Electronics (2020)

- ### Investigating the origins of ultra-short relaxation times of silver filaments in forming-free SiO2-based conductive bridge memristors

  - Panagiotis Bousoulas
  - , Dionisis Sakellaropoulos
  - , Charalampos Papakonstantinopoulos
  - , Stavros Kitsios
  - , Chris Arvanitis
  - , Emmanouil Bagakis
  - & Dimitris Tsoukalas

  Nanotechnology (2020)

- ### Ni(OH)2 based dual-mode memristor

  - Xihua Fan
  - , Fangwang Zhou
  - , Huihong Shao
  - , Ya Li
  - , Xiaobo Chen
  - & Yanli Pei

  Semiconductor Science and Technology (2020)

- ### Investigation of morphological and electrical properties of RTA-processed TiO2 for memristor application

  - S. Roy
  - , S. P. Ghosh
  - , D. Pradhan
  - , P. K. Sahu
  - & J. P. Kar

  Journal of Sol-Gel Science and Technology (2020)

## Comments

By submitting a comment you agree to abide by our Terms and Community Guidelines. If you find something abusive or that does not comply with our terms or guidelines please flag it as inappropriate.

Download PDF

Sign up for the Nature Briefing newsletter — what matters in science, free to your inbox daily.

Email address
I agree my information will be processed in accordance with the Nature and Springer Nature Limited Privacy Policy.
Get the most important science stories of the day, free in your inbox. Sign up for Nature Briefing